@@ -5,6 +5,10 @@ from telemeta.models.location import *
 from telemeta.models.language import *
 from telemeta.models.system import *
 from django.contrib import admin
+from django.contrib.auth.models import User
+from django.contrib.auth.admin import UserAdmin
+
+admin.site.unregister(User)
 
 class MediaFondsAdmin(admin.ModelAdmin):
     search_fields = ['title', 'code']
@@ -15,7 +19,7 @@ class MediaCorpusAdmin(admin.ModelAdmin):
     search_fields = ['title', 'code']
     ordering = ['code']
     filter_horizontal = ['children']
-    
+
 class MediaCollectionAdmin(admin.ModelAdmin):
     search_fields = ['title', 'code']
     ordering = ['code']
@@ -72,7 +76,13 @@ class RevisionAdmin(admin.ModelAdmin):
     ordering = ['-time']
 
 class FormatAdmin(admin.ModelAdmin):
-    search_fields = ['code', 'vendor']
+    search_fields = ['original_code', 'tape_reference']
+
+class UserProfileInline(admin.StackedInline):
+	model = UserProfile
+
+class UserProfileAdmin(UserAdmin):
+	inlines = [UserProfileInline]
 
 admin.site.register(MediaFonds, MediaFondsAdmin)
 admin.site.register(MediaCorpus, MediaCorpusAdmin)
@@ -89,7 +99,7 @@ admin.site.register(InstrumentRelation, InstrumentRelationAdmin)
 admin.site.register(InstrumentAliasRelation, InstrumentAliasRelationAdmin)
 
 admin.site.register(Location, LocationAdmin)
-#admin.site.register(LocationType)
+admin.site.register(LocationType)
 admin.site.register(LocationAlias, LocationAliasAdmin)
 admin.site.register(LocationRelation, LocationRelationAdmin)
 
@@ -98,3 +108,5 @@ admin.site.register(Language, LanguageAdmin)
 admin.site.register(Revision, RevisionAdmin)
 
 admin.site.register(Format, FormatAdmin)
+
+admin.site.register(User, UserProfileAdmin)
