@@ -38,7 +38,7 @@ from django.conf.urls.defaults import *
 from django.conf import settings
 from django.views.generic.simple import redirect_to
 from telemeta.models import MediaItem, MediaCollection, MediaItemMarker, MediaCorpus, MediaFonds
-from telemeta.views.base import GeneralView, AdminView, CollectionView, ItemView, \
+from telemeta.views import HomeView, AdminView, CollectionView, ItemView, \
                                 InstrumentView, PlaylistView, ProfileView, GeoView, \
                                 LastestRevisionsFeed, ResourceView, UserRevisionsFeed
 from jsonrpc import jsonrpc_site
@@ -48,7 +48,7 @@ import telemeta.config
 telemeta.config.check()
 
 # initialization
-general_view = GeneralView()
+home_view = HomeView()
 admin_view = AdminView()
 collection_view = CollectionView()
 item_view = ItemView()
@@ -71,10 +71,10 @@ all_fonds = { 'queryset': MediaFonds.objects.all().order_by('title') }
 # ID's regular expressions
 export_extensions = "|".join(item_view.list_export_extensions())
 
-htdocs = os.path.dirname(__file__) + '/htdocs'
+htdocs = os.path.dirname(__file__) + '/static/telemeta'
 
 urlpatterns = patterns('',
-    url(r'^$', general_view.home, name="telemeta-home"),
+    url(r'^$', home_view.home, name="telemeta-home"),
 
     # items
     url(r'^archives/items/$', 'django.views.generic.list_detail.object_list',
@@ -112,6 +112,10 @@ urlpatterns = patterns('',
         dict(template='telemeta/mediaitem_add.html'), name="telemeta-item-add"),
     url(r'^archives/items/(?P<public_id>[A-Za-z0-9._-]+)/player/(?P<width>[0-9]+)x(?P<height>[0-9]+)/$', item_view.item_detail,
         dict(template='telemeta/mediaitem_player.html'), name="telemeta-item-player"),
+    url(r'^archives/items/(?P<public_id>[A-Za-z0-9._-]+)/player/(?P<width>[0-9]+)x(?P<height>[0-9]+)/simple/$', item_view.item_detail,
+        dict(template='telemeta/mediaitem_player_simple.html'), name="telemeta-item-player-simple"),
+    url(r'^archives/items/(?P<public_id>[A-Za-z0-9._-]+)/player/(?P<width>[0-9]+)x(?P<height>[0-9]+)/countour/$', item_view.item_detail,
+        dict(template='telemeta/mediaitem_player_contour.html'), name="telemeta-item-player-contour"),
     url(r'^archives/items/(?P<public_id>[A-Za-z0-9._-]+)/performances/$', item_view.item_performances_edit,
         dict(template='telemeta/mediaitem_performances_edit.html'), name="telemeta-item-performances_edit"),
     url(r'^archives/items/(?P<public_id>[A-Za-z0-9._-]+)/keywords/$', item_view.item_keywords_edit,
@@ -120,7 +124,7 @@ urlpatterns = patterns('',
     url(r'^archives/items/(?P<item_public_id>[A-Za-z0-9._-]+)/related/(?P<media_id>[A-Za-z0-9._-]+)$', item_view.related_media_item_stream, name="telemeta-item-related"),
     url(r'^archives/items/(?P<public_id>[A-Za-z0-9._-]+)/related_edit/$', item_view.related_media_edit,  dict(template='telemeta/mediaitem_related_edit.html'), name="telemeta-item-related_edit"),
     # Markers
-    url(r'^markers/(?P<marker_id>[A-Za-z0-9]+)/$', item_view.item_detail, name="telemeta-item-detail-marker"),
+    url(r'^archives/markers/(?P<marker_id>[A-Za-z0-9]+)/$', item_view.item_detail, name="telemeta-item-detail-marker"),
     # FIXME: need all paths
     url(r'^items/(?P<path>[A-Za-z0-9._-s/]+)/$', redirect_to, {'url': '/archives/items/%(path)s/', 'permanent': False}, name="telemeta-item-redir"),
 
@@ -166,6 +170,7 @@ urlpatterns = patterns('',
     # Corpus list
     url(r'^archives/corpus/$', 'django.views.generic.list_detail.object_list',
         dict(all_corpus, paginate_by=20, template_name="telemeta/resource_list.html", extra_context={'type':'corpus'}), name="telemeta-corpus"),
+
     # Fonds list
     url(r'^archives/fonds/$', 'django.views.generic.list_detail.object_list',
         dict(all_fonds, paginate_by=20, template_name="telemeta/resource_list.html", extra_context={'type':'fonds'}), name="telemeta-fonds"),
@@ -190,21 +195,21 @@ urlpatterns = patterns('',
     url(r'^archives/(?P<type>[A-Za-z0-9._-]+)/(?P<public_id>[A-Za-z0-9._-]+)/dc/xml/$', resource_view.detail,
         {'format': 'dublin_core_xml'},
         name="telemeta-resource-dublincore-xml"),
-    url(r'^archives/$', general_view.search, name="telemeta-archives"),
+    url(r'^archives/$', home_view.search, name="telemeta-archives"),
 
     # search
-    url(r'^search/$', general_view.search, name="telemeta-search"),
-    url(r'^search/collections/$', general_view.search, {'type': 'collections'},
+    url(r'^search/$', home_view.search, name="telemeta-search"),
+    url(r'^search/collections/$', home_view.search, {'type': 'collections'},
         name="telemeta-search-collections"),
-    url(r'^search/items/$', general_view.search, {'type': 'items'},
+    url(r'^search/items/$', home_view.search, {'type': 'items'},
         name="telemeta-search-items"),
-    url(r'^search/corpus/$', general_view.search, {'type': 'corpus'},
+    url(r'^search/corpus/$', home_view.search, {'type': 'corpus'},
         name="telemeta-search-corpus"),
-    url(r'^search/fonds/$', general_view.search, {'type': 'fonds'},
+    url(r'^search/fonds/$', home_view.search, {'type': 'fonds'},
         name="telemeta-search-fonds"),
 
-    url(r'^search/criteria/$', general_view.edit_search, name="telemeta-search-criteria"),
-    url(r'^complete_location/$', general_view.complete_location, name="telemeta-complete-location"),
+    url(r'^search/criteria/$', home_view.edit_search, name="telemeta-search-criteria"),
+    url(r'^complete_location/$', home_view.complete_location, name="telemeta-complete-location"),
 
     # administration
     url(r'^admin/$', admin_view.admin_index, name="telemeta-admin"),
@@ -282,32 +287,37 @@ urlpatterns = patterns('',
     url(r'^timeside/(?P<path>.*)$', 'django.views.static.serve',
         {'document_root': htdocs+'/timeside'},
         name="telemeta-timeside"),
+    url(r'^video-js/(?P<path>.*)$','django.views.static.serve',
+        {'document_root': htdocs+'/video-js'},
+        name="telemeta-video-js"),
 
     # Flat pages
-    url(r'^pages/(?P<path>.*)$', general_view.render_flatpage, name="telemeta-flatpage"),
+    url(r'^pages/(?P<path>.*)$', home_view.render_flatpage, name="telemeta-flatpage"),
 
     # OAI-PMH Data Provider
-    url(r'^oai/.*$', general_view.handle_oai_request, name="telemeta-oai"),
+    url(r'^oai/.*$', home_view.handle_oai_request, name="telemeta-oai"),
 
     # Authentication
     url(r'^login/$', 'django.contrib.auth.views.login', {'template_name': 'telemeta/login.html'},
         name="telemeta-login"),
+    url(r'^accounts/login/$', 'django.contrib.auth.views.login', {'template_name': 'telemeta/login.html'},
+        name="telemeta-login"),
     #url(r'^login/$', 'ipauth.views.login', {'template_name': 'telemeta/login.html'},
     #    name="telemeta-login"),
-    url(r'^logout/$', general_view.logout, name="telemeta-logout"),
+    url(r'^logout/$', home_view.logout, name="telemeta-logout"),
 
     # Users
-    url(r'^users/$', general_view.users, name="telemeta-users"),
+    url(r'^accounts/$', home_view.users, name="telemeta-users"),
 
     # Desk
-    url(r'^desk/lists/$', general_view.lists, name="telemeta-desk-lists"),
+    url(r'^desk/lists/$', home_view.lists, name="telemeta-desk-lists"),
     url(r'^desk/profile/(?P<username>[A-Za-z0-9._-]+)/$', profile_view.profile_detail, name="telemeta-desk-profile"),
-    url(r'^desk/home/$', general_view.home, name="telemeta-desk-home"),
+    url(r'^desk/home/$', home_view.home, name="telemeta-desk-home"),
 
     # Profiles
-    url(r'^users/(?P<username>[A-Za-z0-9._-]+)/profile/$', profile_view.profile_detail, name="telemeta-profile-detail"),
-    url(r'^users/(?P<username>[A-Za-z0-9._-]+)/profile/edit/$', profile_view.profile_edit, name="telemeta-profile-edit"),
-    url(r'^users/(?P<username>[A-Za-z0-9._-]+)/rss/$', UserRevisionsFeed(),  name="telemeta-user-rss"),
+    url(r'^accounts/(?P<username>[A-Za-z0-9._-]+)/profile/$', profile_view.profile_detail, name="telemeta-profile-detail"),
+    url(r'^accounts/(?P<username>[A-Za-z0-9._-]+)/profile/edit/$', profile_view.profile_edit, name="telemeta-profile-edit"),
+    url(r'^accounts/(?P<username>[A-Za-z0-9._-]+)/rss/$', UserRevisionsFeed(),  name="telemeta-user-rss"),
 
     # Registration
     url(r'^accounts/password_change/$', 'django.contrib.auth.views.password_change', {'template_name': 'telemeta/registration/password_change_form.html'}, name="telemeta-password-change"),
